Author: tkreuzer
Date: Sat Jan 30 02:46:16 2010
New Revision: 45334
URL:
http://svn.reactos.org/svn/reactos?rev=45334&view=rev
Log:
fix macros...
Modified:
branches/ros-amd64-bringup/reactos/include/reactos/asm.h
Modified: branches/ros-amd64-bringup/reactos/include/reactos/asm.h
URL:
http://svn.reactos.org/svn/reactos/branches/ros-amd64-bringup/reactos/inclu…
==============================================================================
--- branches/ros-amd64-bringup/reactos/include/reactos/asm.h [iso-8859-1] (original)
+++ branches/ros-amd64-bringup/reactos/include/reactos/asm.h [iso-8859-1] Sat Jan 30
02:46:16 2010
@@ -18,7 +18,7 @@
#define VAL(x) x
/* MASM/ML doesn't want explicit [rip] addressing */
-#define RIP(address) address
+#define RIP(address) [address]
/* Due to MASM's reverse syntax, we are forced to use a precompiler macro */
#define MACRO(name, ...) name MACRO __VA_ARGS__
@@ -33,8 +33,13 @@
name ENDP
ENDM
-/* MASM doesn't have an ASCIIZ macro */
-.ASCIIZ MACRO text
+/* MASM doesn't have an ASCII macro */
+.ASCII MACRO text
+ DB text
+ENDM
+
+/* MASM doesn't have an ASCIZ macro */
+.ASCIZ MACRO text
DB text, 0
ENDM
@@ -98,13 +103,14 @@
.set cfa_current_offset, cfa_current_offset - \size
.endm
-.macro .pushframe code
- .if (\code == 0)
+code = 1
+.macro .pushframe param=0
+ .if (\param)
+ .cfi_adjust_cfa_offset 0x30
+ .set cfa_current_offset, cfa_current_offset - 0x30
+ .else
.cfi_adjust_cfa_offset 0x28
.set cfa_current_offset, cfa_current_offset - 0x28
- .else
- .cfi_adjust_cfa_offset 0x30
- .set cfa_current_offset, cfa_current_offset - 0x30
.endif
.endm